@@ -8,7 +8,7 @@ __copyright__ = "Copyright (C) 2018 Vijay Varma"
 __email__ = "vvarma@caltech.edu"
 __status__ = "testing"
 __author__ = "Vijay Varma"
-__version__ = "1.1.3"
+__version__ = "1.1.8"
 __license__ = """
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -176,6 +176,11 @@ See _fit_evaluators.fit_7dq2.py for an example.
         if chiBmag > 1 + 1e-14:
             raise ValueError('Spin magnitude of BhB > 1.')
 
+        chiA = np.atleast_1d(chiA)
+        chiB = np.atleast_1d(chiB)
+        if len(chiA) != 3 or len(chiB) != 3:
+            raise TypeError("Expected input spins to be 3-vectors.")
+
         if self.aligned_spin_only:
             if np.sqrt(np.sum(chiA[:2]**2)) > 1e-14:
                 raise ValueError('The x & y components of chiA should be zero.')
